Functions
::::::::::

.. toctree::
   :maxdepth: 3

   functioncalls.rst
   builtin.rst
   typeconversion.rst
   mathfunctions.rst
   randomnumbers.rst
   addingnewfunctions.rst
   definitionsanduses.rst
   flowofexecution.rst
   parametersandargs.rst
   fruitfulvoid.rst
   whyfunctions.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   mixedupcode.rst
   WriteCode.rst
   func-group.rst
   functions_exercises.rst
   functions_mixedupcode.rst
   functions_writecode.rst
   func-string.rst
   function_string_exercises.rst
   function_string_mixedUpCode.rst
   function_string_writecode.rst
   funcWithCond.rst
   function_conditional_exercises.rst
   function_conditional_mixedupcode.rst
   function_conditional_writecode.rst
   funcWithLists.rst
   function_list_exercises.rst
   function_list_mixedupcode.rst
   function_list_writecode.rst
   funcWithLoops.rst
   functions_loops_exercises.rst
   functions_loops_mixedupcode.rst
   functions_loops_writecode.rst
   funcWithTuplesAndDict.rst
   functions_tups_dicts_exercises.rst
   functions_tups_dicts_mixedupcode.rst
   functions_tups_dicts_writecode.rst
   func_Str_Cond.rst
   funcWithListsAndLoops.rst

